"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.destination = void 0;
const tslib_1 = require("tslib");
const shim_1 = require("@segment/browser-destination-runtime/shim");
const addPaymentInfo_1 = tslib_1.__importDefault(require("./addPaymentInfo"));
const addToCart_1 = tslib_1.__importDefault(require("./addToCart"));
const addToWishlist_1 = tslib_1.__importDefault(require("./addToWishlist"));
const beginCheckout_1 = tslib_1.__importDefault(require("./beginCheckout"));
const customEvent_1 = tslib_1.__importDefault(require("./customEvent"));
const login_1 = tslib_1.__importDefault(require("./login"));
const generateLead_1 = tslib_1.__importDefault(require("./generateLead"));
const purchase_1 = tslib_1.__importDefault(require("./purchase"));
const refund_1 = tslib_1.__importDefault(require("./refund"));
const removeFromCart_1 = tslib_1.__importDefault(require("./removeFromCart"));
const search_1 = tslib_1.__importDefault(require("./search"));
const selectItem_1 = tslib_1.__importDefault(require("./selectItem"));
const selectPromotion_1 = tslib_1.__importDefault(require("./selectPromotion"));
const signUp_1 = tslib_1.__importDefault(require("./signUp"));
const viewCart_1 = tslib_1.__importDefault(require("./viewCart"));
const viewItem_1 = tslib_1.__importDefault(require("./viewItem"));
const viewItemList_1 = tslib_1.__importDefault(require("./viewItemList"));
const viewPromotion_1 = tslib_1.__importDefault(require("./viewPromotion"));
const setConfigurationFields_1 = tslib_1.__importDefault(require("./setConfigurationFields"));
const actions_core_1 = require("@segment/actions-core");
const presets = [
    {
        name: `Set Configuration Fields`,
        subscribe: 'type = "page"',
        partnerAction: 'setConfigurationFields',
        mapping: actions_core_1.defaultValues(setConfigurationFields_1.default.fields),
        type: 'automatic'
    }
];
exports.destination = {
    name: 'Google Analytics 4 Web',
    slug: 'actions-google-analytics-4-web',
    mode: 'device',
    settings: {
        measurementID: {
            description: 'The measurement ID associated with the web stream. Found in the Google Analytics UI under: Admin > Data Streams > Web > Measurement ID.',
            label: 'Measurement ID',
            type: 'string',
            required: true
        },
        allowGoogleSignals: {
            description: 'Set to false to disable all advertising features. Set to true by default.',
            label: 'Allow Google Signals',
            type: 'boolean',
            default: true
        },
        allowAdPersonalizationSignals: {
            description: 'Set to false to disable all advertising features. Set to true by default.',
            label: 'Allow Ad Personalization Signals',
            type: 'boolean',
            default: true
        },
        cookieDomain: {
            description: 'Specifies the domain used to store the analytics cookie. Set to “auto” by default.',
            label: 'Cookie Domain',
            type: 'string',
            default: 'auto'
        },
        cookieExpirationInSeconds: {
            description: `Every time a hit is sent to GA4, the analytics cookie expiration time is updated to be the current time plus the value of this field. The default value is two years (63072000 seconds). Please input the expiration value in seconds. More information in [Google Documentation](https://developers.google.com/analytics/devguides/collection/ga4/reference/config#)`,
            label: 'Cookie Expiration In Seconds',
            type: 'number',
            default: 63072000
        },
        cookieFlags: {
            description: `Appends additional flags to the analytics cookie.  See [write a new cookie](https://developer.mozilla.org/en-US/docs/Web/API/Document/cookie#write_a_new_cookie) for some examples of flags to set.`,
            label: 'Cookie Flag',
            type: 'string',
            default: undefined,
            multiple: true
        },
        cookiePath: {
            description: `Specifies the subpath used to store the analytics cookie. We recommend to add a forward slash, / , in the first field as it is the Default Value for GA4.`,
            label: 'Cookie Path',
            type: 'string',
            default: '/'
        },
        cookiePrefix: {
            description: `Specifies a prefix to prepend to the analytics cookie name.`,
            label: 'Cookie Prefix',
            type: 'string',
            default: undefined,
            multiple: true
        },
        cookieUpdate: {
            description: `Set to false to not update  cookies on each page load. This has the effect of cookie expiration being relative to the first time a user visited. Set to true by default so update cookies on each page load.`,
            label: 'Cookie Update',
            type: 'boolean',
            default: true
        },
        enableConsentMode: {
            description: `Set to true to enable Google’s [Consent Mode](https://support.google.com/analytics/answer/9976101?hl=en). Set to false by default.`,
            label: 'Enable Consent Mode',
            type: 'boolean',
            default: false
        },
        defaultAdsStorageConsentState: {
            description: 'The default value for ad cookies consent state. This is only used if Enable Consent Mode is on. Set to  “granted” if it is not explicitly set. Consent state can be updated for each user in the Set Configuration Fields action.',
            label: 'Default Ads Storage Consent State',
            type: 'string',
            choices: [
                { label: 'Granted', value: 'granted' },
                { label: 'Denied', value: 'denied' }
            ],
            default: 'granted',
            depends_on: {
                conditions: [
                    {
                        fieldKey: 'enableConsentMode',
                        operator: 'is',
                        value: true
                    }
                ]
            }
        },
        defaultAnalyticsStorageConsentState: {
            description: 'The default value for analytics cookies consent state. This is only used if Enable Consent Mode is on. Set to  “granted” if it is not explicitly set. Consent state can be updated for each user in the Set Configuration Fields action.',
            label: 'Default Analytics Storage Consent State',
            type: 'string',
            choices: [
                { label: 'Granted', value: 'granted' },
                { label: 'Denied', value: 'denied' }
            ],
            default: 'granted',
            depends_on: {
                conditions: [
                    {
                        fieldKey: 'enableConsentMode',
                        operator: 'is',
                        value: true
                    }
                ]
            }
        },
        adUserDataConsentState: {
            description: 'Consent state indicated by the user for ad cookies. Value must be "granted" or "denied." This is only used if the Enable Consent Mode setting is on.',
            label: 'Ad User Data Consent State',
            type: 'string',
            choices: [
                { label: 'Granted', value: 'granted' },
                { label: 'Denied', value: 'denied' }
            ],
            default: undefined,
            depends_on: {
                conditions: [
                    {
                        fieldKey: 'enableConsentMode',
                        operator: 'is',
                        value: true
                    }
                ]
            }
        },
        adPersonalizationConsentState: {
            description: 'Consent state indicated by the user for ad cookies. Value must be "granted" or "denied." This is only used if the Enable Consent Mode setting is on.',
            label: 'Ad Personalization Consent State',
            type: 'string',
            choices: [
                { label: 'Granted', value: 'granted' },
                { label: 'Denied', value: 'denied' }
            ],
            default: undefined,
            depends_on: {
                conditions: [
                    {
                        fieldKey: 'enableConsentMode',
                        operator: 'is',
                        value: true
                    }
                ]
            }
        },
        waitTimeToUpdateConsentStage: {
            description: 'If your CMP loads asynchronously, it might not always run before the Google tag. To handle such situations, specify a millisecond value to control how long to wait before the consent state update is sent. Please input the wait_for_update in milliseconds.',
            label: 'Wait Time to Update Consent State',
            type: 'number'
        },
        pageView: {
            description: 'Set to false to prevent the default snippet from sending page views. Enabled by default.',
            label: 'Page Views',
            type: 'boolean',
            default: true
        }
    },
    initialize: async ({ settings }, deps) => {
        window.dataLayer = window.dataLayer || [];
        window.gtag = function () {
            window.dataLayer.push(arguments);
        };
        window.gtag('js', new Date());
        if (settings.enableConsentMode) {
            const consent = {
                ad_storage: settings.defaultAdsStorageConsentState,
                analytics_storage: settings.defaultAnalyticsStorageConsentState,
                wait_for_update: settings.waitTimeToUpdateConsentStage
            };
            if (settings.adUserDataConsentState) {
                consent.ad_user_data = settings.adUserDataConsentState;
            }
            if (settings.adPersonalizationConsentState) {
                consent.ad_personalization = settings.adPersonalizationConsentState;
            }
            gtag('consent', 'default', consent);
        }
        const script = `https://www.googletagmanager.com/gtag/js?id=${settings.measurementID}`;
        await deps.loadScript(script);
        return window.gtag;
    },
    presets,
    actions: {
        addPaymentInfo: addPaymentInfo_1.default,
        login: login_1.default,
        signUp: signUp_1.default,
        search: search_1.default,
        addToCart: addToCart_1.default,
        addToWishlist: addToWishlist_1.default,
        removeFromCart: removeFromCart_1.default,
        selectItem: selectItem_1.default,
        selectPromotion: selectPromotion_1.default,
        viewItem: viewItem_1.default,
        viewPromotion: viewPromotion_1.default,
        beginCheckout: beginCheckout_1.default,
        purchase: purchase_1.default,
        refund: refund_1.default,
        viewCart: viewCart_1.default,
        viewItemList: viewItemList_1.default,
        generateLead: generateLead_1.default,
        customEvent: customEvent_1.default,
        setConfigurationFields: setConfigurationFields_1.default
    }
};
exports.default = shim_1.browserDestination(exports.destination);
//# sourceMappingURL=index.js.map